@@ -104,7 +104,12 @@ class CommonBrowserView(BrowserView):
         return structure
     
     def getLeadMediaTag(self, item, scale="large"):
-        if hasattr(item, 'leadMedia'):
+        if item.portal_type == "Collection":
+            media = self.getCollectionMedia()
+            lead = None
+            if len(media) > 0:
+                lead = media[0]
+        elif hasattr(item, 'leadMedia'):
             lead = item.leadMedia
         else:
             catalog = getToolByName(self.context, 'portal_catalog')
@@ -118,8 +123,35 @@ class CommonBrowserView(BrowserView):
                 return '<img src="%(url)s" alt="%(title)s" title="%(title)s" />'%{'url': "%s/image_%s"%(lead, scale), 'title':item.Title}
         else:
             return ""
-        
+
+    def getCollectionMedia(self, item):
+        results = []
+        if item.portal_type == "Collection":
+            if hasattr(item, 'getObject'):
+                obj = item.getObject()
+            else:
+                obj = item
+                
+            results = obj.queryCatalog()
+                
+            resultArray = []
+            for res in results:
+                if res.portal_type == "Image":
+                    resultArray.append(res)
+                elif res.portal_type == "Link" and (res.getRemoteUrl.find("youtube.com") > -1 or res.getRemoteUrl.find("vimeo.com") > -1):
+                    resultArray.append(res)
+                else:
+                    if res.hasMedia:
+                        resultArray.append(res.leadMedia)
+            
+            return resultArray
+        else:
+            return results
+
     def containsMedia(self, item):
+        if item.portal_type == "Collection":
+            return len(self.getCollectionMedia(item)) > 0
+        
         if hasattr(item, 'hasMedia'):
             return item.hasMedia
         else:
@@ -231,7 +263,7 @@ class CommonBrowserView(BrowserView):
         closingHour = event.end() is not None and event.end().strftime('to %H:%M') or ""
         hoursExist = 'to %s'%openingHour != closingHour
         
-        hours = hoursExist and ', <span class="hours">%s %s</span>'%(openingHour, closingHour) or ''
+        hours = hoursExist and '<span class="hours">, %s %s</span>'%(openingHour, closingHour) or '<span class="hours">, %s</span>'%openingHour
         
         finalDates = finalDatesFmt%{'class': self.isEventPast(event) and 'past' or 'future', 'dates': dates, 'hours': hours, 'exceptions':exceptions}
         
